{% extends "base.html" %}

{% block content %}
    {% for p in chapter_page %}
    <li>
        <a href="{{ url_for('.comic_page', path=p.path) }}">chapter: {{ p.chapter }}</a>
    {% endfor %}
    {% for p in book_page %}
    <ul>
        <a href="{{ url_for('.comic_page', path=p.path) }}"> {{ p.title }} </a>
    </ul>
    {% endfor %}
    </li>
{% endblock content %}
{% block content_footer %}
{% endblock content_footer %}
