DEBUG = True
FLATPAGES_AUTO_RELOAD = DEBUG
FLATPAGES_EXTENSION = '.md'
FLATPAGES_ROOT = 'content'
FREEZER_DESTINATION_IGNORE = ['.git*', '.gitignore', 'CNAME']
FEEZER_RELATIVE_URLS = True
SITE_NAME = '3color Press Site'
BUILD_DIR = 'build'
BOOK_DIR = 'book'
PAGE_DIR = 'single'
NEWS_DIR = 'news'
DOMAIN = ''
MAIN_STORY = ''
THUMB_STORY = ''
USER_NAME = ''
REMOTE_SERVER = ''
PUB_METHOD = 'local'
ACTIVE_THEME = 'default'
