{% extends "base.html" %}
{% block title %}
  <h2 id="page_title">{{p.title}}</h2>
{% endblock title %}
{% block content %}
<div id="comic">
    <img src="{{ url_for('.images', name=p.book.image) }}">
</div>
{% block lowerbooknav %}
  {% include '_book_nav.html' %}
{% endblock lowerbooknav %}
{% endblock  content%}
{% block content_footer %}
{% endblock content_footer %}
