{% extends "base.html" %}
{% block title %}
  {% for p in front_page %}
  <h2 id="page_title">{{p.title}}</h2>
  {% endfor %}
{% endblock title %}
{% block content %}
  <div id="comic">
      {% for p in front_page %}
      <a href="{{ url_for('.comic_page', _anchor='content', book=p.book.title, chapter=p.book.chapter, number=p.book.page_number, name=p.path.replace(config.BOOK_DIR+'/', '')) }}"> <img src="{{ url_for('.images', name=p.book.image) }}"></a>
      {% endfor %}
  </div>
{% block lowerbooknav %}
{% include '_book_nav.html' %}
{% endblock lowerbooknav %}
{% endblock content %}
{% block content_footer %}
<h2 id="page_title"> Recent Updates</h2>
{% for p in news_page %}
<div id="news_blurb">
<div class="news_blurb {{ loop.cycle('odd', 'even') }}">
  <h2 id="page_title"><a href="{{ url_for('.news_page', name=p.path.replace('news/', '')) }}">{{ p.title }}</a></h2>
    {{ p.body|truncate(255) }}
    <a href="{{ url_for('.news_page', name=p.path.replace('news/', '')) }}"> read more</a>
</div>
</div>
{% endfor %}
{% endblock content_footer %}
