{% extends "base.html" %}
{% block title %}
    <h2 id="page_title">{{ page.title }}</h2>
{% endblock title %}
{% block content %}
    <div id="single_page">
        {{ page }}
    </div>
{% block content_footer %}
{% endblock content_footer %}
{% endblock content %}
